serverpod_chat_flutter library

Classes

ChatController
Handles all interaction with a chat channel.
ChatDispatch
The ChatDispatch receives chat related messages from the server and passes them on to the correct ChatController.
ChatInput
Input control for the chat. Typically, a chat is setup using a ChatInput and a ChatView.
ChatInputState
The state of a ChatInput.
ChatView
A ChatView displays a scrollable list of chat messages associated with the controller. The messages are rendered using the tileBuilder. To create a custom look for the chat messages, provide a custom ChatTileBuilder.
ChatViewState
The state of the ChatView.
A Text widget with tappable links. The text is parsed and url links are styled and made tappable. On tap, they will open the url in the default browser.
TextWithLinksState
The state of TextWithLinks.

Typedefs

ChatControllerReceivedMessageCallback = void Function(ChatMessage message, bool addedByUser)
Callback for when a message is received from the server. If addedByUser is true, the message was added by the current user.
ChatMessageListener = void Function(SerializableModel message)
Callback for received chat messages.
ChatTileBuilder = Widget Function(BuildContext context, ChatMessage message, ChatMessage? previous)
Builds a new chat tile. By default the DefaultChatTile is used.